# Mobicoop V3 - Auth Service

Authentication (AuthN) and Authorization (AuthZ) data management.

## Installation

You need [Docker](https://docs.docker.com/engine/) and [Docker-compose](https://docs.docker.com/compose/).

Copy `.env.dist` to `.env` :

```bash
cp .env.dist .env
```

and modify it to suit your needs.

Then execute :

```bash
docker-compose up -d
```

The app runs automatically on the port defined in `SERVICE_PORT` of `.env` file (default : _5002_).

You then need to set the appropriate rights for PGAdmin container :

```bash
sudo chown -R 5050:5050 postgresql/.pgadmin_data
```

## Database migration

Before using the app, you need to launch the database migration :

```bash
docker exec v3_user sh -c "npx prisma migrate dev"
```

## Usage

The app exposes the following [gRPC](https://grpc.io/) services :

-   **Create** : create an auth

    ```json
    {
        "uuid": "30f49838-3f24-42bb-a489-8ffb480173ae",
        "username": "john.doe@email.com",
        "password": "John123"
    }
    ```

-   **Update** : update an auth (username and/or password)

    ```json
    {
        "uuid": "30f49838-3f24-42bb-a489-8ffb480173ae",
        "username": "johnny.doe@email.com",
        "password": "John1234"
    }
    ```

-   **Validate** : validate an auth (= authentication with username/password)

    ```json
    {
        "username": "john.doe@email.com",
        "password": "John123"
    }
    ```

## Test

```bash
# unit tests
docker exec v3_user sh -c "npm run test"

# test coverage
docker exec v3_user sh -c "npm run test:cov"
```

Note : you can run all npm commands directly _outside_ the container (see _scripts_ section of `package.json` for available commands), but you need NodeJS installed locally. We **strongly** advise to install [Node Version Manager](https://github.com/nvm-sh/nvm) and use the latest LTS version of Node.

## License

Mobicoop V3 - Auth Service is [AGPL licensed](LICENSE).
