import { CommandHandler } from '@nestjs/cqrs';
import { AuthRepository } from '../../adapters/secondaries/auth.repository';
import { UsernameRepository } from '../../adapters/secondaries/username.repository';
import { DeleteAuthCommand } from '../../commands/delete-auth.command';

@CommandHandler(DeleteAuthCommand)
export class DeleteAuthUseCase {
  constructor(
    private readonly _authRepository: AuthRepository,
    private readonly _usernameRepository: UsernameRepository,
  ) {}

  async execute(command: DeleteAuthCommand) {
    try {
      await this._usernameRepository.deleteMany({
        uuid: command.deleteAuthRequest.uuid,
      });
      return await this._authRepository.delete({
        uuid: command.deleteAuthRequest.uuid,
      });
    } catch (e) {
      throw e;
    }
  }
}
