import { CommandHandler } from '@nestjs/cqrs';
import { AuthRepository } from '../../adapters/secondaries/auth.repository';
import { Auth } from '../entities/auth';
import * as bcrypt from 'bcrypt';
import { UpdatePasswordCommand } from '../../commands/update-password.command';

@CommandHandler(UpdatePasswordCommand)
export class UpdatePasswordUseCase {
  constructor(private readonly _authRepository: AuthRepository) {}

  async execute(command: UpdatePasswordCommand): Promise<Auth> {
    const { uuid, password } = command.updatePasswordRequest;
    const hash = await bcrypt.hash(password, 10);

    try {
      return await this._authRepository.update(uuid, {
        password: hash,
      });
    } catch (e) {
      throw e;
    }
  }
}
