import { classes } from '@automapper/classes';
import { AutomapperModule } from '@automapper/nestjs';
import { Test, TestingModule } from '@nestjs/testing';
import { AuthRepository } from '../../adapters/secondaries/auth.repository';
import { UsernameRepository } from '../../adapters/secondaries/username.repository';
import { DeleteAuthCommand } from '../../commands/delete-auth.command';
import { DeleteAuthRequest } from '../../domain/dtos/delete-auth.request';
import { Type } from '../../domain/dtos/type.enum';
import { DeleteAuthUseCase } from '../../domain/usecases/delete-auth.usecase';

const usernames = {
  data: [
    {
      uuid: 'cf76af29-f75d-4f6e-bb40-4ecbcfa3356e',
      username: 'john.doe@email.com',
      type: Type.EMAIL,
    },
    {
      uuid: 'cf76af29-f75d-4f6e-bb40-4ecbcfa3356e',
      username: '0611223344',
      type: Type.PHONE,
    },
  ],
  total: 2,
};

const deleteAuthRequest: DeleteAuthRequest = {
  uuid: 'bb281075-1b98-4456-89d6-c643d3044a91',
};
const deleteAuthCommand: DeleteAuthCommand = new DeleteAuthCommand(
  deleteAuthRequest,
);

const mockAuthRepository = {
  delete: jest.fn().mockResolvedValue(undefined),
};

const mockUsernameRepository = {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  findAll: jest.fn().mockImplementation((page, perPage, query) => {
    return Promise.resolve(usernames);
  }),
  delete: jest.fn().mockResolvedValue(undefined),
  deleteMany: jest.fn().mockResolvedValue(undefined),
};

describe('DeleteAuthUseCase', () => {
  let deleteAuthUseCase: DeleteAuthUseCase;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [AutomapperModule.forRoot({ strategyInitializer: classes() })],
      providers: [
        {
          provide: AuthRepository,
          useValue: mockAuthRepository,
        },
        {
          provide: UsernameRepository,
          useValue: mockUsernameRepository,
        },
        DeleteAuthUseCase,
      ],
    }).compile();

    deleteAuthUseCase = module.get<DeleteAuthUseCase>(DeleteAuthUseCase);
  });

  it('should be defined', () => {
    expect(deleteAuthUseCase).toBeDefined();
  });

  describe('execute', () => {
    it('should delete an auth and its usernames', async () => {
      const deletedAuth = await deleteAuthUseCase.execute(deleteAuthCommand);

      expect(deletedAuth).toBe(undefined);
    });
  });
});
